-- pdfclock.lua (based on pdfclock.c)

RADIUS=200
MARGIN=20

p = PDF_new()

assert(PDF_open_file(p, "pdfclock.pdf"))

PDF_set_info(p, "Creator", "pdfclock.lua")
PDF_set_info(p, "Author", "Thomas Merz")
PDF_set_info(p, "Title", "PDF clock (Lua)")

PDF_begin_page(p, 2 * (RADIUS + MARGIN), 2 * (RADIUS + MARGIN))

PDF_translate(p, RADIUS + MARGIN, RADIUS + MARGIN)
PDF_setcolor(p, "both", "rgb", 0, 0, 1, 0)
PDF_save(p)

-- minute strokes
PDF_setlinewidth(p, 2)
for alpha = 0,360-6,6 do
    PDF_rotate(p, 6)
    PDF_moveto(p, RADIUS, 0)
    PDF_lineto(p, RADIUS-MARGIN/3, 0)
    PDF_stroke(p)
end

PDF_restore(p)
PDF_save(p)

-- 5 minute strokes
PDF_setlinewidth(p, 3)
for alpha = 0,360-30,30 do
    PDF_rotate(p, 30)
    PDF_moveto(p, RADIUS, 0)
    PDF_lineto(p, RADIUS-MARGIN, 0)
    PDF_stroke(p)
end

_,_,hour,min,sec=strfind(date"%T","(%d+):(%d+):(%d+)")

-- draw hour hand
PDF_save(p)
PDF_rotate(p, -((min/60) + hour - 3) * 30)
PDF_moveto(p, -RADIUS/10, -RADIUS/20)
PDF_lineto(p, RADIUS/2, 0)
PDF_lineto(p, -RADIUS/10, RADIUS/20)
PDF_closepath(p)
PDF_fill(p)
PDF_restore(p)

-- draw minute hand
PDF_save(p)
PDF_rotate(p, -((sec/60) + min - 15) * 6)
PDF_moveto(p, -RADIUS/10, -RADIUS/20)
PDF_lineto(p, RADIUS * 0.8, 0)
PDF_lineto(p, -RADIUS/10, RADIUS/20)
PDF_closepath(p)
PDF_fill(p)
PDF_restore(p)

-- draw second hand
PDF_setcolor(p, "both", "rgb", 1, 0, 0, 0)
PDF_setlinewidth(p, 2)
PDF_save(p)
PDF_rotate(p, -((sec - 15) * 6))
PDF_moveto(p, -RADIUS/5, 0)
PDF_lineto(p, RADIUS, 0)
PDF_stroke(p)
PDF_restore(p)

-- draw little circle at center
PDF_circle(p, 0, 0, RADIUS/30)
PDF_fill(p)

PDF_restore(p)

PDF_end_page(p)

PDF_close(p)
PDF_delete(p)
